<?php
/**
* @package phpBB Extension - TV Wrap BBCode
* @copyright (c) 2024 Sniper_E - http://sniper-e.net
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\tvwrap\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	/** @var \phpbb\user */
	protected $user;
	/** @var \phpbb\template\template */
	protected $template;
	/** @var \phpbb\auth\auth */
	protected $auth;
	/** @var \phpbb\config\config */
	protected $config;

	/**
	* Constructor
	*
	* @param \phpbb\user                 $user
	* @param \phpbb\template\template    $template
	* @param \phpbb\auth\auth            $auth
	* @param \phpbb\config\config        $config
	*
	*/
	public function __construct(\phpbb\user $user, \phpbb\template\template $template, \phpbb\auth\auth $auth, \phpbb\config\config $config)
	{
		$this->user     = $user;
		$this->template = $template;
		$this->auth     = $auth;
		$this->config   = $config;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.permissions'           => 'permissions',
			'core.user_setup'            => 'load_language_on_setup',
		);
	}

	public function permissions($event)
	{
		$permissions = $event['permissions'];
		$permissions['u_use_tvwrap_bbcode'] = array('lang' => 'ACL_U_USE_TVWRAP_BBCODE', 'cat' => 'post');
		$event['permissions'] = $permissions;
	}

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'sniper/tvwrap',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}
}
