<?php
/**
* @package phpBB Extension - TV Wrap BBCode
* @copyright (c) 2024 Sniper_E - http://sniper-e.net
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\tvwrap\migrations;

class update_tvwrap extends \phpbb\db\migration\migration
{
	public function update_data()
	{
		return array(
			array('custom', array(array($this, 'install_tvwrap_bbcodes'))),
			// Permission
			array('permission.add', array('u_use_tvwrap_bbcode', true)),
			// Set Permission
			array('permission.permission_set', array('ADMINISTRATORS', 'u_use_tvwrap_bbcode', 'group', true)),
		);
	}
	public function revert_data()
	{
		return array(
			array('custom', array(array(&$this, 'tvwrap_bbcodes_behind'))),
		);
	}
	/**
	 * notebbcodes left behind, hides the bbcode buttons on posting
	 *
	 * @param array $bbcode_tags Array of noteBBCodes tags to hide
	 * @return null
	 * @access public
	 */
	public function tvwrap_bbcodes_behind($bbcode_tags)
	{
	/**
	 * @var array An array of notebbcodes (tags) to be left behind
	 */
	$bbcode_tags = array('tvwrap');
	// set to null the display on posting
	$sql = 'UPDATE ' . BBCODES_TABLE . '
		SET display_on_posting = 1
		WHERE ' . $this->db->sql_in_set('bbcode_tag', $bbcode_tags);
		$this->db->sql_query($sql);
	}
	/**
	 * Installs BBCodes, used by migrations to perform add/updates
	 *
	 * @param array $bbcode_data Array of BBCode data to install
	 * @return null
	 * @access public
	 */
	public function install_tvwrap_bbcodes($bbcode_data)
	{
		// Load the acp_bbcode class
		if (!class_exists('acp_bbcodes'))
		{
			include($this->phpbb_root_path . 'includes/acp/acp_bbcodes.' . $this->php_ext);
		}
		$bbcode_tool = new \acp_bbcodes();
		/**
		 * @var array An array of bbcodes data to install
		 */
		$bbcode_data = array(
			'tvwrap' => array(
				'bbcode_match'       => '[tvwrap={NUMBER1},{NUMBER2}]{URL}[/tvwrap]',
				'bbcode_tpl'         => '<table class="media-wrap">
	<tr>
		<td class="headertv-leftcorner"></td>
		<td class="headertv-center" colspan="3"></td>
		<td class="headertv-rightcorner"></td>
	</tr>
	<tr>
		<td class="lefttv-wrap"></td>
		<td class="centertv-wrap" colspan="3"><iframe width="{NUMBER1}" height="{NUMBER2}" src="{URL}" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe></td>
		<td class="righttv-wrap"></td>
	</tr>
	<tr>
		<td class="footertv-leftcorner"></td>
		<td class="footertv-center" colspan="3"></td>
		<td class="footertv-rightcorner"></td>
	</tr>
	<tr>
		<td class="tvstand-leftcorner"></td>
		<td class="tvstand-left"></td>
		<td class="tvstand-center"></td>
		<td class="tvstand-right"></td>
		<td class="tvstand-rightcorner"></td>
	</tr>
</table>',
				'bbcode_helpline'    => 'TV Wrap: [tvwrap][video=300,150]URL[/video][/tvwrap]',
				'display_on_posting' => 1,
			),
		);
		foreach ($bbcode_data as $bbcode_name => $bbcode_array)
		{
			// Build the BBCodes
			$data = $bbcode_tool->build_regexp($bbcode_array['bbcode_match'], $bbcode_array['bbcode_tpl'], $bbcode_array['bbcode_helpline']);
			$bbcode_array += array(
				'bbcode_tag'          => $data['bbcode_tag'],
				'first_pass_match'    => $data['first_pass_match'],
				'first_pass_replace'  => $data['first_pass_replace'],
				'second_pass_match'   => $data['second_pass_match'],
				'second_pass_replace' => $data['second_pass_replace']
			);
			$sql = 'SELECT bbcode_id
				FROM ' . BBCODES_TABLE . "
				WHERE LOWER(bbcode_tag) = '" . strtolower($bbcode_name) . "'
				OR LOWER(bbcode_tag) = '" . strtolower($bbcode_array['bbcode_tag']) . "'";
			$result = $this->db->sql_query($sql);
			$row_exists = $this->db->sql_fetchrow($result);
			$this->db->sql_freeresult($result);
			if ($row_exists)
			{
				// Update existing BBCode
				$bbcode_id = $row_exists['bbcode_id'];
				$sql = 'UPDATE ' . BBCODES_TABLE . '
					SET ' . $this->db->sql_build_array('UPDATE', $bbcode_array) . '
					WHERE bbcode_id = ' . $bbcode_id;
				$this->db->sql_query($sql);
			}
			else
			{
				// Create new BBCode
				$sql = 'SELECT MAX(bbcode_id) AS max_bbcode_id
					FROM ' . BBCODES_TABLE;
				$result = $this->db->sql_query($sql);
				$max_bbcode_id = $this->db->sql_fetchfield('max_bbcode_id');
				$this->db->sql_freeresult($result);
				if ($max_bbcode_id)
				{
					$bbcode_id = $max_bbcode_id + 1;
					// Make sure it is greater than the core BBCode ids...
					if ($bbcode_id <= NUM_CORE_BBCODES)
					{
						$bbcode_id = NUM_CORE_BBCODES + 1;
					}
				}
				else
				{
					$bbcode_id = NUM_CORE_BBCODES + 1;
				}
				if ($bbcode_id <= BBCODE_LIMIT)
				{
					$bbcode_array['bbcode_id'] = (int) $bbcode_id;
					$bbcode_array['display_on_posting'] = ((int) $bbcode_array['display_on_posting']);
					$this->db->sql_query('INSERT INTO ' . BBCODES_TABLE . ' ' . $this->db->sql_build_array('INSERT', $bbcode_array));
				}
			}
		}
	}
}
